@@ -13,6 +13,7 @@ REGIONS = {
     'CA': 'us-east-1',
     'FR': 'eu-west-1',
     'DE': 'eu-west-1',
+    'NL': 'eu-west-1',
     'IN': 'eu-west-1',
     'IT': 'eu-west-1',
     'JP': 'us-west-2',
@@ -31,6 +32,7 @@ DOMAINS = {
     'CA': 'ca',
     'FR': 'fr',
     'DE': 'de',
+    'NL': 'nl',
     'IN': 'in',
     'IT': 'it',
     'JP': 'co.jp',
