@@ -31,11 +31,11 @@ class AmazonAPI:
         secret (str): Your API secret.
         tag (str): The tag you want to use for the URL.
         country (str): Country code. Use one of the following:
-            AU, BR, CA, FR, DE, IN, IT, JP, MX, ES, TR, AE, UK, US.
+            AU, BR, CA, FR, DE, IN, NL, IT, JP, MX, ES, TR, AE, UK, US.
         throttling (float, optional): It should be greater than 0 or False to disable throttling.
         This value determines wait time between API calls.
     """
-    def __init__(self, key: str, secret: str, tag: str, country: str, throttling=0.8):
+    def __init__(self, key, secret, tag, country, throttling=0.8):
         self.key = key
         self.secret = secret
         self.tag = tag
@@ -68,7 +68,7 @@ class AmazonAPI:
                 time.sleep(wait_time)
         self.last_query_time = time.time()
 
-    def get_products(self, product_ids: [str, list], condition='Any', merchant='All',
+    def get_products(self, product_ids, condition='Any', merchant='All',
                      async_req=False):
         """Find product information for multiple products on Amazon.
 
@@ -138,12 +138,12 @@ class AmazonAPI:
         else:
             return None
 
-    def get_product(self, product_id: str, condition='Any', merchant='All',
+    def get_product(self, product_id, condition='Any', merchant='All',
                     async_req=False):
         """Find product information for a specific product on Amazon.
 
         Args:
-            product_id (str): One item ID like ASIN or product URL.
+            product_id (str, list): One item ID like ASIN or product URL.
             condition (str, optional): Specify the product condition.
                 Allowed values: Any, Collectible, New, Refurbished, Used.
                 Defaults to Any.
@@ -158,12 +158,10 @@ class AmazonAPI:
                 for the product or None if no results.
         """
         if isinstance(product_id, list):
-            raise AmazonException('TypeError', 'Arg product_id should be string')
+            product_id = product_id[0]
         if isinstance(product_id, str):
-            check_product_id = product_id.split(',')
-            if len(check_product_id) > 1:
-                raise AmazonException('ValueError', 'Only 1 product ID is allowed, use '
-                                                    'get_products for multiple requests')
+            product_id = product_id.split(',')[0]
+
         product = self.get_products(product_id, condition=condition, merchant=merchant,
                                     async_req=async_req)
         if product:
